****************************************************************************************************
*                                           PROGRAM OVERVIEW
****************************************************************************************************
*
* PROGRAM: ms_qrpe_createpov5.sas  
*
* Created (mm/dd/yyyy): 02/01/2018
* Last modified: 
* Version: 1.0
*
*--------------------------------------------------------------------------------------------------
* PURPOSE:
*	This program will identify events of interest during an encounter

*  Program inputs:                                                                                   
*	-Dataset with valid encounters (_EncMasterList)  
*   -Dataset with claims defined as being potential events
* 
*  Program outputs:                                                                                                                                       
* 	-Dataset with valid events
* 
* PARAMETERS:
*
*  Programming Notes:                                                                                
*                                                                           
*
*--------------------------------------------------------------------------------------------------
* CONTACT INFO: 
*  Sentinel Coordinating Center
*  info@sentinelsystem.org
*
*--------------------------------------------------------------------------------------------------
*  CHANGE LOG: 
*
*   Version   Date       Initials	   Comment (reference external documentation when available)
*   -------   --------   --------   ---------------------------------------------------------------
*
***************************************************************************************************;

%macro ms_qrpe_createpov5();

%put =====> MACRO CALLED: ms_qrpe_createpov5 v1.0;

	%if %eval(&num_hoi>0) %then %do;

	 *Identify encounters with events;
        proc sql noprint;
        create table _encounterswithevents as
        select distinct index.Patid,
                        index.encounterID,
                        substr(FUP,4) as Event,
						1 as HOI
        from _EncMasterList as index, 
             _FUPEvent as Inc
        where index.Patid = Inc.Patid and index.encounterID = inc.encounterID
		order by patid, encounterID;
        quit;

	*Transpose to 1 row per encounter;
		proc transpose data=_encounterswithevents out=_encounterswithevents_byID(drop=_:) prefix=event;
		    by patid encounterID ;
		    id event;
		    var HOI;
		run;

	*Ensure all events represented (variable will be missing if no encounter has an event);
		data _encounterswithevents_byID;
			set _encounterswithevents_byID;
				if _n_ = 1 then do;
					dsid = open("_encounterswithevents_byID");
						%do num=1 %to %eval(&num_hoi.);
						if varnum(dsid,"Event&num.") = 0 then event&num. =0;
						%end;
					rc= close(dsid);
				end;
			drop rc dsid;
		run;
	%end;
	%else %do;
		data _encounterswithevents_byID;
			set _EncMasterList(obs=0);
				if _n_ = 1 then do;
					dsid = open("_EncMasterList");
						%do num=1 %to %eval(&num_hoi.);
						if varnum(dsid,"Event&num.") = 0 then event&num. =0;
						%end;
					rc= close(dsid);
				end;
			drop rc dsid;

			keep patid encounterID %if %eval(&num_hoi.>0) %then event:; ;
		run;
	%end;

%put NOTE: ********END OF MACRO: ms_qrpe_createpov5 v1.0********;

%mend ms_qrpe_createpov5;
